@@ -5,7 +5,7 @@ import itertools
 import unittest
 
 from wpull.string import to_bytes, to_str, detect_encoding, printable_bytes, \
-    normalize_codec_name, format_size
+    normalize_codec_name, format_size, printable_str
 
 
 class TestString(unittest.TestCase):
@@ -102,6 +102,24 @@ class TestString(unittest.TestCase):
             printable_bytes(b' 1234\x00abc XYZ\xff~')
         )
 
+    def test_printable_str(self):
+        self.assertEqual(
+            'asdf',
+            printable_str('asdf')
+        )
+        self.assertEqual(
+            'asdf\\n',
+            printable_str('asdf\n')
+        )
+        self.assertEqual(
+            'asdf\n',
+            printable_str('asdf\n', keep_newlines=True)
+        )
+        self.assertEqual(
+            'as\\x1bdf',
+            printable_str('as\x1bdf')
+        )
+
     def test_normalize_codec_name(self):
         self.assertEqual('utf-8', normalize_codec_name('UTF-8'))
         self.assertEqual('utf-8', normalize_codec_name('uTF_8'))
